@@ -59,6 +59,21 @@ def test_generated_parser():
     assert "Add a new completer" in add_cmd.description
     assert (
         alias.parser.format_usage()
-        == "usage: completer [-h] {add,remove,rm,list,ls} ...\n"
+        == "usage: completer [-h] {add,remove,rm,list,ls,complete} ...\n"
     )
     assert add_cmd.format_usage() == "usage: completer add [-h] name func [pos]\n"
+
+
+def test_parser_hooking():
+    from xonsh.history.main import HistoryAlias
+
+    alias = HistoryAlias()
+
+    parser, _ = cli_utils.ArgparseCompleter.get_parser(alias.parser, ["show"])
+    assert parser._get_positional_actions()[0].choices == (
+        "session",
+        "xonsh",
+        "all",
+        "zsh",
+        "bash",
+    )
