@@ -3,27 +3,29 @@ Tests for command pipelines.
 """
 
 import os
+
 import pytest
 
 from xonsh.platform import ON_WINDOWS
 from xonsh.procs.pipelines import CommandPipeline
-from tests.tools import skip_if_on_windows, skip_if_on_unix
-from xonsh.built_ins import XSH
+from xonsh.pytest.tools import skip_if_on_unix, skip_if_on_windows
 
 
 @pytest.fixture(autouse=True)
-def patched_events(monkeypatch, xonsh_events, xonsh_execer):
-    from xonsh.jobs import tasks
+def patched_events(monkeypatch, xonsh_events, xonsh_session):
+    from xonsh.jobs import get_tasks
 
-    tasks.clear()
+    get_tasks().clear()
     # needed for ci tests
     monkeypatch.setitem(
-        XSH.env, "RAISE_SUBPROC_ERROR", False
+        xonsh_session.env, "RAISE_SUBPROC_ERROR", False
     )  # for the failing `grep` commands
-    monkeypatch.setitem(XSH.env, "XONSH_CAPTURE_ALWAYS", True)  # capture output of ![]
+    monkeypatch.setitem(
+        xonsh_session.env, "XONSH_CAPTURE_ALWAYS", True
+    )  # capture output of ![]
     if ON_WINDOWS:
         monkeypatch.setattr(
-            XSH,
+            xonsh_session.commands_cache,
             "aliases",
             {
                 "echo": "cmd /c echo".split(),
@@ -110,3 +112,10 @@ def test_raw_substitution(xonsh_execer):
 )
 def test_casting(cmdline, result, xonsh_execer):
     assert xonsh_execer.eval(f"{cmdline}") == result
+
+
+@skip_if_on_windows
+def test_background_pgid(xonsh_session, monkeypatch):
+    monkeypatch.setitem(xonsh_session.env, "XONSH_INTERACTIVE", True)
+    pipeline = xonsh_session.execer.eval("![echo hi &]")
+    assert pipeline.term_pgid is not None
