@@ -65,7 +65,7 @@ _cases = {
             (Literal.String.Double, "hello"),
             (Literal.String.Double, '"'),
             (Punctuation, ")"),
-            (Text, "\n"),
+            (Text.Whitespace, "\n"),
         ]
     },
     "invalid-cmd": {
@@ -111,7 +111,7 @@ _cases = {
             (Name.Builtin, "cd"),
             (Punctuation, ")"),
             (Punctuation, ")"),
-            (Text, "\n"),
+            (Text.Whitespace, "\n"),
         ],
         r'print(![echo "])\""])': [
             (Name.Builtin, "print"),
@@ -123,7 +123,7 @@ _cases = {
             (Literal.String.Double, '"])\\""'),
             (Punctuation, "]"),
             (Punctuation, ")"),
-            (Text, "\n"),
+            (Text.Whitespace, "\n"),
         ],
     },
     "subproc-args": {
