@@ -205,7 +205,7 @@ def ansi_color_style(style="default"):
         cmap = ANSI_STYLES[style]
     else:
         msg = f"Could not find color style {style!r}, using default."
-        warnings.warn(msg, RuntimeWarning)
+        warnings.warn(msg, RuntimeWarning, stacklevel=2)
         cmap = ANSI_STYLES["default"]
     return cmap
 
@@ -294,10 +294,8 @@ def ansi_color_escape_code_to_name(escape_code, style, reversed_style=None):
     # strip some actual escape codes, if needed.
     match = ANSI_ESCAPE_CODE_RE.match(escape_code)
     if not match:
-        msg = 'Invalid ANSI color sequence "{}", using "RESET" instead.'.format(
-            escape_code
-        )
-        warnings.warn(msg, RuntimeWarning)
+        msg = f'Invalid ANSI color sequence "{escape_code}", using "RESET" instead.'
+        warnings.warn(msg, RuntimeWarning, stacklevel=2)
         return ("RESET",)
     ec = match.group(2)
     names = []
