@@ -25,7 +25,6 @@ from ast import (
     BitXor,
     BoolOp,
     Break,
-    Bytes,
     Call,
     ClassDef,
     Compare,
@@ -72,13 +71,12 @@ from ast import (
     Module,
     Mult,
     Name,
-    NameConstant,
+    NamedExpr,
     NodeTransformer,
     Nonlocal,
     Not,
     NotEq,
     NotIn,
-    Num,
     Or,
     Pass,
     Pow,
@@ -90,7 +88,6 @@ from ast import (
     Slice,
     Starred,
     Store,
-    Str,
     Sub,
     Subscript,
     Try,
@@ -113,15 +110,10 @@ from ast import (
     walk,
     withitem,
 )
-from ast import Ellipsis as EllipsisNode
 
 from xonsh.built_ins import XSH
-from xonsh.platform import PYTHON_VERSION_INFO
 from xonsh.tools import find_next_break, get_logical_line, subproc_toks
 
-if PYTHON_VERSION_INFO > (3, 8):
-    from ast import NamedExpr  # type:ignore
-
 STATEMENTS = (
     FunctionDef,
     ClassDef,
@@ -148,6 +140,38 @@ STATEMENTS = (
 )
 
 
+def const_str(s: str, **kwargs):
+    return Constant(value=s, kind="str", **kwargs)
+
+
+def is_const_str(node):
+    return isinstance(node, Constant) and node.kind == "str"
+
+
+def const_bytes(s: str, **kwargs):
+    return Constant(value=s, kind="bytes", **kwargs)
+
+
+def is_const_bytes(node):
+    return isinstance(node, Constant) and node.kind == "bytes"
+
+
+def const_num(n, **kwargs):
+    return Constant(value=n, kind="num", **kwargs)
+
+
+def is_const_num(node):
+    return isinstance(node, Constant) and node.kind == "num"
+
+
+def const_name(value, **kwargs):
+    return Constant(value=value, kind="name", **kwargs)
+
+
+def is_const_name(node):
+    return isinstance(node, Constant) and node.kind == "name"
+
+
 def leftmostname(node):
     """Attempts to find the first name in the tree."""
     if isinstance(node, Name):
@@ -166,7 +190,7 @@ def leftmostname(node):
         rtn = leftmostname(node.targets[0])
     elif isinstance(node, AnnAssign):
         rtn = leftmostname(node.target)
-    elif isinstance(node, (Str, Bytes, JoinedStr)):
+    elif isinstance(node, JoinedStr) or is_const_str(node) or is_const_bytes(node):
         # handles case of "./my executable"
         rtn = leftmostname(node.s)
     elif isinstance(node, Tuple) and len(node.elts) > 0:
@@ -670,8 +694,8 @@ def _getblockattr(name, lineno, col):
         "getattr",
         args=[
             Name(id=name, ctx=Load(), lineno=lineno, col_offset=col),
-            Str(s="__xonsh_block__", lineno=lineno, col_offset=col),
-            NameConstant(value=False, lineno=lineno, col_offset=col),
+            const_str(s="__xonsh_block__", lineno=lineno, col_offset=col),
+            const_name(value=False, lineno=lineno, col_offset=col),
         ],
         lineno=lineno,
         col=col,
