@@ -92,7 +92,16 @@ def reglob(path, parts=None, i=None):
             base = ""
         elif len(parts) > 1:
             i += 1
-    regex = re.compile(parts[i])
+    try:
+        regex = re.compile(parts[i])
+    except Exception as e:
+        if isinstance(e, re.error) and str(e) == "nothing to repeat at position 0":
+            raise XonshError(
+                "Consider adding a leading '.' to your glob regex pattern."
+            ) from e
+        else:
+            raise e
+
     files = os.listdir(subdir)
     files.sort()
     paths = []
@@ -548,7 +557,7 @@ class XonshSession:
         self.commands_cache = None
         self.modules_cache = None
         self.all_jobs = None
-        self.completers = None
+        self._completers = None
         self.builtins = None
         self._initial_builtin_names = None
 
@@ -558,6 +567,15 @@ class XonshSession:
             return
         return self.commands_cache.aliases
 
+    @property
+    def completers(self):
+        """Returns a list of all available completers. Init when first accessing the attribute"""
+        if self._completers is None:
+            from xonsh.completers.init import default_completers
+
+            self._completers = default_completers(self.commands_cache)
+        return self._completers
+
     def _disable_python_exit(self):
         # Disable Python interactive quit/exit
         if hasattr(builtins, "exit"):
@@ -585,7 +603,6 @@ class XonshSession:
             Context to start xonsh session with.
         """
         from xonsh.commands_cache import CommandsCache
-        from xonsh.completers.init import default_completers
         from xonsh.environ import Env, default_env
 
         if not hasattr(builtins, "__xonsh__"):
@@ -619,7 +636,6 @@ class XonshSession:
         )
         self.link_builtins()
         self.builtins_loaded = True
-        self.completers = default_completers(self.commands_cache)
 
         def flush_on_exit(s=None, f=None):
             if self.history is not None:
@@ -663,6 +679,7 @@ class XonshSession:
         self.unlink_builtins()
         delattr(builtins, "__xonsh__")
         self.builtins_loaded = False
+        self._completers = None
 
 
 def get_default_builtins(execer=None):
