@@ -1,12 +1,10 @@
-# -*- coding: utf-8 -*-
 """Tools for diff'ing two xonsh history files in a meaningful fashion."""
-import difflib
 import datetime
+import difflib
 import itertools
 
-from xonsh.lazyjson import LazyJSON
 from xonsh.color_tools import COLORS
-
+from xonsh.lazyjson import LazyJSON
 
 # intern some strings
 REPLACE_S = "replace"
@@ -38,15 +36,11 @@ def bold_str_diff(a, b, sm=None):
 
 
 def redline(line):
-    return "{red}- {line}{reset}\n".format(
-        red=COLORS.RED, line=line, reset=COLORS.RESET
-    )
+    return f"{COLORS.RED}- {line}{COLORS.RESET}\n"
 
 
 def greenline(line):
-    return "{green}+ {line}{reset}\n".format(
-        green=COLORS.GREEN, line=line, reset=COLORS.RESET
-    )
+    return f"{COLORS.GREEN}+ {line}{COLORS.RESET}\n"
 
 
 def highlighted_ndiff(a, b):
@@ -78,7 +72,7 @@ def highlighted_ndiff(a, b):
     return s
 
 
-class HistoryDiffer(object):
+class HistoryDiffer:
     """This class helps diff two xonsh history files."""
 
     def __init__(self, afile, bfile, reopen=False, verbose=False):
@@ -141,7 +135,7 @@ class HistoryDiffer(object):
             bval = benv[key]
             if aval == bval:
                 continue
-            s += "{0!r} is in both, but differs\n".format(key)
+            s += f"{key!r} is in both, but differs\n"
             s += bold_str_diff(aval, bval, sm=sm) + "\n"
         return s
 
@@ -150,12 +144,10 @@ class HistoryDiffer(object):
         if len(only_x) == 0:
             return ""
         if self.verbose:
-            xstr = ",\n".join(
-                ["    {0!r}: {1!r}".format(key, xenv[key]) for key in only_x]
-            )
+            xstr = ",\n".join([f"    {key!r}: {xenv[key]!r}" for key in only_x])
             xstr = "\n" + xstr
         else:
-            xstr = ", ".join(["{0!r}".format(key) for key in only_x])
+            xstr = ", ".join([f"{key!r}" for key in only_x])
         in_x = "These vars are only in {color}{xid}{reset}: {{{xstr}}}\n\n"
         return in_x.format(xid=xid, color=color, reset=COLORS.RESET, xstr=xstr)
 
@@ -207,14 +199,10 @@ class HistoryDiffer(object):
             pass
         elif bout is None:
             aid = self.a["sessionid"]
-            s += "Note: only {red}{aid}{reset} output stored\n".format(
-                red=COLORS.RED, aid=aid, reset=COLORS.RESET
-            )
+            s += f"Note: only {COLORS.RED}{aid}{COLORS.RESET} output stored\n"
         elif aout is None:
             bid = self.b["sessionid"]
-            s += "Note: only {green}{bid}{reset} output stored\n".format(
-                green=COLORS.GREEN, bid=bid, reset=COLORS.RESET
-            )
+            s += f"Note: only {COLORS.GREEN}{bid}{COLORS.RESET} output stored\n"
         elif aout != bout:
             s += "Outputs differ\n"
             s += highlighted_ndiff(aout.splitlines(), bout.splitlines())
@@ -223,15 +211,7 @@ class HistoryDiffer(object):
         artn = self.a["cmds"][i]["rtn"]
         brtn = self.b["cmds"][j]["rtn"]
         if artn != brtn:
-            s += (
-                "Return vals {red}{artn}{reset} & {green}{brtn}{reset} differ\n"
-            ).format(
-                red=COLORS.RED,
-                green=COLORS.GREEN,
-                reset=COLORS.RESET,
-                artn=artn,
-                brtn=brtn,
-            )
+            s += f"Return vals {COLORS.RED}{artn}{COLORS.RESET} & {COLORS.GREEN}{brtn}{COLORS.RESET} differ\n"
         return s
 
     def _cmd_replace_diff(self, i, ainp, aid, j, binp, bid):
