@@ -313,6 +313,7 @@ def parse_aliases(s, shell, sourcer=None, files=(), extra_args=()):
     if m is None:
         return {}
     g1 = m.group(1)
+    g1 = g1.replace("\\\n", " ")
     items = [
         line.split("=", 1)
         for line in g1.splitlines()
@@ -344,6 +345,7 @@ def parse_aliases(s, shell, sourcer=None, files=(), extra_args=()):
             warnings.warn(
                 f'could not parse alias "{key}": {exc!r}',
                 RuntimeWarning,
+                stacklevel=2,
             )
             continue
         aliases[key] = value
