@@ -191,7 +191,7 @@ class HistoryAlias(xcli.ArgParserAlias):
     def show(
         self,
         session: xcli.Annotated[str, xcli.Arg(nargs="?")] = "session",
-        slices: xcli.Annotated[tp.List[int], xcli.Arg(nargs="*")] = None,
+        slices: xcli.Annotated[list[int], xcli.Arg(nargs="*")] = None,
         datetime_format: tp.Optional[str] = None,
         start_time: tp.Optional[str] = None,
         end_time: tp.Optional[str] = None,
@@ -339,6 +339,19 @@ class HistoryAlias(xcli.ArgParserAlias):
         hist.clear()
         print("History cleared", file=sys.stderr)
 
+    @staticmethod
+    def delete(pattern):
+        """Delete all commands matching a pattern
+
+        Parameters
+        ----------
+        pattern:
+            regex pattern to match against command history
+        """
+        hist = XSH.history
+        deleted = hist.delete(pattern)
+        print(f"Deleted {deleted} entries from history")
+
     @staticmethod
     def file(_stdout):
         """Display the current history filename"""
@@ -371,7 +384,7 @@ class HistoryAlias(xcli.ArgParserAlias):
 
     @staticmethod
     def gc(
-        size: xcli.Annotated[tp.Tuple[int, str], xcli.Arg(nargs=2)] = None,
+        size: xcli.Annotated[tuple[int, str], xcli.Arg(nargs=2)] = None,
         force=False,
         blocking=True,
     ):
@@ -466,6 +479,7 @@ class HistoryAlias(xcli.ArgParserAlias):
         parser.add_command(self.off)
         parser.add_command(self.on)
         parser.add_command(self.clear)
+        parser.add_command(self.delete)
         parser.add_command(self.gc)
         parser.add_command(self.transfer)
 
