@@ -2,6 +2,7 @@
 import collections
 import json
 import os
+import re
 import sqlite3
 import sys
 import threading
@@ -41,8 +42,8 @@ def _xh_sqlite_create_history_table(cursor):
     """
     if not getattr(XH_SQLITE_CACHE, XH_SQLITE_CREATED_SQL_TBL, False):
         cursor.execute(
-            """
-            CREATE TABLE IF NOT EXISTS {}
+            f"""
+            CREATE TABLE IF NOT EXISTS {XH_SQLITE_TABLE_NAME}
                  (inp TEXT,
                   rtn INTEGER,
                   tsb REAL,
@@ -53,9 +54,7 @@ def _xh_sqlite_create_history_table(cursor):
                   frequency INTEGER default 1,
                   cwd TEXT
                  )
-        """.format(
-                XH_SQLITE_TABLE_NAME
-            )
+        """
         )
 
         # add frequency column if not exists for backward compatibility
@@ -222,6 +221,17 @@ def xh_sqlite_wipe_session(sessionid=None, filename=None):
         c.execute(sql, (str(sessionid),))
 
 
+def xh_sqlite_delete_input_matching(pattern, filename=None):
+    """Deletes entries from the database where the input matches a pattern."""
+    with _xh_sqlite_get_conn(filename=filename) as conn:
+        c = conn.cursor()
+        _xh_sqlite_create_history_table(c)
+        for inp, *_ in _xh_sqlite_get_records(c):
+            if pattern.match(inp):
+                sql = f"DELETE FROM xonsh_history WHERE inp = '{inp}'"
+                c.execute(sql)
+
+
 class SqliteHistoryGC(threading.Thread):
     """Shell history garbage collection."""
 
@@ -387,3 +397,9 @@ class SqliteHistory(History):
         self.cwds = []
 
         xh_sqlite_wipe_session(sessionid=self.sessionid, filename=self.filename)
+
+    def delete(self, pattern):
+        """Deletes all entries in the database where the input matches a pattern."""
+        xh_sqlite_delete_input_matching(
+            pattern=re.compile(pattern), filename=self.filename
+        )
