@@ -184,7 +184,8 @@ def parser():
     )
     p.add_argument(
         "--no-rc",
-        help="Do not load any xonsh RC files.",
+        help="Do not load any xonsh RC files. Argument --rc will "
+        "be ignored if --no-rc is set.",
         dest="norc",
         action="store_true",
         default=False,
@@ -280,18 +281,13 @@ class XonshMode(enum.Enum):
 
 
 def _get_rc_files(shell_kwargs: dict, args, env):
+    if shell_kwargs.get("norc"):
+        # if --no-rc was passed, then disable loading RC files and dirs
+        return (), ()
+
     # determine which RC files to load, including whether any RC directories
     # should be scanned for such files
     rc_cli = shell_kwargs.get("rc")
-    if shell_kwargs.get("norc") or (
-        args.mode != XonshMode.interactive
-        and not args.force_interactive
-        and not args.login
-    ):
-        # if --no-rc was passed, or we're not in an interactive shell and
-        # interactive mode was not forced, then disable loading RC files and dirs
-        return (), ()
-
     if rc_cli:
         # if an explicit --rc was passed, then we should load only that RC
         # file, and nothing else (ignore both XONSHRC and XONSHRC_DIR)
@@ -634,5 +630,6 @@ def setup(
     XSH.aliases.update(aliases)
     if xontribs:
         xontribs_load(xontribs)
-    tp = XSH.commands_cache.threadable_predictors
-    tp.update(threadable_predictors)
+
+    if threadable_predictors:
+        XSH.commands_cache.threadable_predictors.update(threadable_predictors)
