@@ -1,13 +1,12 @@
-# -*- coding: utf-8 -*-
 """Completer implementation to use with prompt_toolkit."""
 import os
 
-from prompt_toolkit.completion import Completer, Completion
-from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 from prompt_toolkit.application.current import get_app
+from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
+from prompt_toolkit.completion import Completer, Completion
 
-from xonsh.completers.tools import RichCompletion
 from xonsh.built_ins import XSH
+from xonsh.completers.tools import RichCompletion
 
 
 class PromptToolkitCompleter(Completer):
@@ -73,6 +72,7 @@ class PromptToolkitCompleter(Completer):
             if sug_comp is None:
                 pass
             elif len(completions) == 0:
+                plen = len(prefix)
                 completions = (sug_comp,)
             else:
                 completions = set(completions)
