@@ -3,7 +3,6 @@ import os
 import re
 import stat
 import sys
-import typing as tp
 from collections import ChainMap
 from collections.abc import MutableMapping
 from keyword import iskeyword
@@ -66,7 +65,7 @@ from xonsh.tools import (
 Color = Token.Color  # alias to new color token namespace
 
 # style rules that are not supported by pygments are stored here
-NON_PYGMENTS_RULES: tp.Dict[str, tp.Dict[str, str]] = {}
+NON_PYGMENTS_RULES: dict[str, dict[str, str]] = {}
 
 # style modifiers not handled by pygments (but supported by ptk)
 PTK_SPECIFIC_VALUES = frozenset(
@@ -1490,7 +1489,7 @@ def on_lscolors_change(key, oldvalue, newvalue, **kwargs):
 events.on_lscolors_change(on_lscolors_change)
 
 
-def color_file(file_path: str, path_stat: os.stat_result) -> tp.Tuple[_TokenType, str]:
+def color_file(file_path: str, path_stat: os.stat_result) -> tuple[_TokenType, str]:
     """Determine color to use for file *approximately* as ls --color would,
        given lstat() results and its path.
 
@@ -1750,7 +1749,7 @@ class XonshConsoleLexer(XonshLexer):
 
     name = "Xonsh console lexer"
     aliases = ["xonshcon"]
-    filenames: tp.List[str] = []
+    filenames: list[str] = []
 
     tokens = {
         "root": [
