@@ -1108,7 +1108,7 @@ def display_colored_error_message(exc_info, strip_xonsh_error_types=True, limit=
     # color the traceback if available
     _, interactive = _get_manual_env_var("XONSH_INTERACTIVE", 0)
     _, color_results = _get_manual_env_var("COLOR_RESULTS", 0)
-    if not interactive and not color_results and not HAS_PYGMENTS:
+    if not interactive or not color_results or not HAS_PYGMENTS:
         sys.stderr.write(traceback_str)
         return
 
@@ -2118,8 +2118,8 @@ def _token_attr_from_stylemap(stylemap):
     else:
         style = ptk.styles.style_from_pygments_dict(stylemap)
         for token in stylemap:
-            style_str = "class:{}".format(
-                ptk.styles.pygments.pygments_token_to_classname(token)
+            style_str = (
+                f"class:{ptk.styles.pygments.pygments_token_to_classname(token)}"
             )
             yield (token, style.get_attrs_for_style_str(style_str))
 
@@ -2708,7 +2708,7 @@ def columnize(elems, width=80, newline="\n"):
     data = [elems[i * nrows : (i + 1) * nrows] for i in range(ncols)]
     colwidths = [max(map(len, d)) + pad for d in data]
     colwidths[-1] -= pad
-    row_t = "".join(["{{row[{i}]: <{{w[{i}]}}}}".format(i=i) for i in range(ncols)])
+    row_t = "".join([f"{{row[{i}]: <{{w[{i}]}}}}" for i in range(ncols)])
     row_t += newline
     lines = [
         row_t.format(row=row, w=colwidths)
@@ -2791,8 +2791,8 @@ def deprecated(deprecated_in=None, removed_in=None):
 
 def _deprecated_message_suffix(deprecated_in, removed_in):
     if deprecated_in and removed_in:
-        message_suffix = " in version {} and will be removed in version {}".format(
-            deprecated_in, removed_in
+        message_suffix = (
+            f" in version {deprecated_in} and will be removed in version {removed_in}"
         )
     elif deprecated_in and not removed_in:
         message_suffix = f" in version {deprecated_in}"
