@@ -47,11 +47,10 @@ from xonsh.tools import (
     print_exception,
     to_bool,
 )
-from xonsh.xontribs import find_xontrib, xontribs_loaded
-from xonsh.xontribs_meta import Xontrib, get_xontribs
+from xonsh.xontribs import Xontrib, find_xontrib, get_xontribs, xontribs_loaded
 
 HR = "'`-.,_,.-*'`-.,_,.-*'`-.,_,.-*'`-.,_,.-*'`-.,_,.-*'`-.,_,.-*'`-.,_,.-*'"
-WIZARD_HEAD = """
+WIZARD_HEAD = f"""
           {{BOLD_WHITE}}Welcome to the xonsh configuration wizard!{{RESET}}
           {{YELLOW}}------------------------------------------{{RESET}}
 This will present a guided tour through setting up the xonsh static
@@ -70,13 +69,11 @@ variable setup. Each phase may be skipped in its entirety.
 
 For the configuration to take effect, you will need to restart xonsh.
 
-{hr}
-""".format(
-    hr=HR
-)
+{HR}
+"""
 
-WIZARD_FS = """
-{hr}
+WIZARD_FS = f"""
+{HR}
 
                       {{BOLD_WHITE}}Foreign Shell Setup{{RESET}}
                       {{YELLOW}}-------------------{{RESET}}
@@ -88,12 +85,10 @@ aliases, and functions specified in the config files of these shells.
 Naturally, these shells must be available on the system to work.
 Being able to share configuration (and source) from foreign shells
 makes it easier to transition to and from xonsh.
-""".format(
-    hr=HR
-)
+"""
 
-WIZARD_ENV = """
-{hr}
+WIZARD_ENV = f"""
+{HR}
 
                   {{BOLD_WHITE}}Environment Variable Setup{{RESET}}
                   {{YELLOW}}--------------------------{{RESET}}
@@ -109,14 +104,12 @@ values are presented as pretty repr strings of their Python types.
 
 {{BOLD_GREEN}}Note:{{RESET}} Simply hitting enter for any environment variable
 will accept the default value for that entry.
-""".format(
-    hr=HR
-)
+"""
 
 WIZARD_ENV_QUESTION = "Would you like to set env vars now, " + wiz.YN
 
-WIZARD_XONTRIB = """
-{hr}
+WIZARD_XONTRIB = f"""
+{HR}
 
                            {{BOLD_WHITE}}Xontribs{{RESET}}
                            {{YELLOW}}--------{{RESET}}
@@ -129,9 +122,7 @@ This allows the xontrib to be used immediately in your xonshrc files.
 
 The following describes all xontribs that have been registered with xonsh.
 These come from users, 3rd party developers, or xonsh itself!
-""".format(
-    hr=HR
-)
+"""
 
 WIZARD_XONTRIB_QUESTION = "Would you like to enable xontribs now, " + wiz.YN
 
@@ -139,7 +130,7 @@ WIZARD_TAIL = """
 Thanks for using the xonsh configuration wizard!"""
 
 
-_XONFIG_SOURCE_FOREIGN_SHELL_COMMAND: tp.Dict[str, str] = collections.defaultdict(
+_XONFIG_SOURCE_FOREIGN_SHELL_COMMAND: dict[str, str] = collections.defaultdict(
     lambda: "source-foreign", bash="source-bash", cmd="source-cmd", zsh="source-zsh"
 )
 
@@ -364,24 +355,21 @@ def _xontrib_path(visitor=None, node=None, val=None):
     return ("xontribs", len(visitor.state.get("xontribs", ())))
 
 
-def make_xontrib(xon_item: tp.Tuple[str, Xontrib]):
+def make_xontrib(xon_item: tuple[str, Xontrib]):
     """Makes a message and StoreNonEmpty node for a xontrib."""
     name, xontrib = xon_item
     name = name or "<unknown-xontrib-name>"
     msg = "\n{BOLD_CYAN}" + name + "{RESET}\n"
+
     if xontrib.url:
         msg += "{RED}url:{RESET} " + xontrib.url + "\n"
-    if xontrib.package:
-        pkg = xontrib.package
-        msg += "{RED}package:{RESET} " + pkg.name + "\n"
-        if pkg.url:
-            if xontrib.url and pkg.url != xontrib.url:
-                msg += "{RED}package-url:{RESET} " + pkg.url + "\n"
-        if pkg.license:
-            msg += "{RED}license:{RESET} " + pkg.license + "\n"
+    if xontrib.distribution:
+        msg += "{RED}package:{RESET} " + xontrib.distribution.name + "\n"
+        if xontrib.license:
+            msg += "{RED}license:{RESET} " + xontrib.license + "\n"
     msg += "{PURPLE}installed?{RESET} "
     msg += ("no" if find_xontrib(name) is None else "yes") + "\n"
-    msg += _wrap_paragraphs(xontrib.description, width=69)
+    msg += _wrap_paragraphs(xontrib.get_description(), width=69)
     if msg.endswith("\n"):
         msg = msg[:-1]
     mnode = wiz.Message(message=msg)
@@ -530,7 +518,7 @@ def _info(
         reports results as json
     """
     env = XSH.env
-    data: tp.List[tp.Any] = [("xonsh", XONSH_VERSION)]
+    data: list[tp.Any] = [("xonsh", XONSH_VERSION)]
     hash_, date_ = githash()
     if hash_:
         data.append(("Git SHA", hash_))
